pub fn build_default_engine(symbol: &str) -> TaEngineExpand description
Build a TaEngine with the standard set of indicators used by strategy
templates. The returned engine covers every indicator present in
TechnicalIndicators.
pub fn build_default_engine(symbol: &str) -> TaEngineBuild a TaEngine with the standard set of indicators used by strategy
templates. The returned engine covers every indicator present in
TechnicalIndicators.