pub fn calculate_indicators(candles: &[Candle]) -> TechnicalIndicators👎Deprecated:
Use hyper_ta::dynamic::calculate_snapshot() with TaEngine instead
Calculate all technical indicators from a slice of candles.
The candles are expected to be in chronological order (oldest first).
Indicators that require more data than available will be None.